# ====== 添加PATH并自动去重
function addToPATH() {
  case ":$PATH:" in
  *":$1:"*) : ;;        # already there
  *) PATH="$1:$PATH" ;; # or PATH="$PATH:$1"
  esac
}
function addToPATH2() {
  case ":$PATH:" in
  *":$1:"*) : ;; # already there
  *) PATH="$PATH:$1" ;;
  esac
}

# ====== docker
dockerin() {
  docker exec -it $1 /bin/bash
}
alias dockerps='docker ps --format "table {{.ID}}\t{{.Names}}\t{{.Ports}}"'
alias dockerpsa='docker ps -a --format "table {{.ID}}\t{{.Names}}\t{{.Ports}}"'

# ====== git
alias g='git'
alias ga='git add'
alias gc='git checkout'
alias gm='git commit -m'
alias gb='git branch'
alias gs='git status'

# ====== rc
alias vzshrc='vim ~/.zshrc'
alias rzshrc='source ~/.zshrc'
alias vbashrc='vim ~/.bashrc'
alias rbashrc='source ~/.bashrc'

# ====== 排序-默认 10
duhead() {
  du -sh * | sort -hr | head -n ${1:-10}
}

# ====== 进程查询与关闭
# 自动过滤grep
function tgrep() {
  ps aux | grep $1 | grep -v grep
}
function tkillp() {
  local pid
  pid=$(ps ax | grep $1 | grep -v grep | awk '{ print $1 }')
  kill -9 $pid
  echo -n "Killed $1 (process $pid)"
}
# 关闭端口管理的程序
function tkillport() {
  kill -9 $(lsof -t -i:$1)
}

# ====== IP查询
function iplocal() {
  ifconfig | rg inet | rg -v '127.0.0.1' | rg -v 'inet6' | awk '{print $2}'
}
function ipremote() {
  curl cip.cc
}

# ====== 删除大文件
function rmbigdir() {
  mkdir -p /tmp/blank/
  rsync --delete-before -d /tmp/blank/ $1
}

# ====== tart untart
alias tart='tar -zcvf'
alias untart='tar -zxvf'

sedfile() {
  sed -i "s/$2/$3/g" "$1"
}

#--- 大树科技 k8s 常用命令
getNamespace() {
  read -p "aircpdev aircptest aircpsl
rxdpdev rxdptest rxdpsl: " -r namespace
  echo "${namespace}"
}
getSearch() {
  read -p "请输入关键字：" -r key
  echo "${key}"
}
k8spod() {
  kubectl get pod -n "$(getNamespace)" -owide
}
k8sip() {
  namespace=$(getNamespace)
  key=$(getSearch)
  kubectl get pod -n "${namespace}" -owide | grep "${key}"
}
k8slog() {
  namespace=$(getNamespace)
  key=$(getSearch)
  pod=$(kubectl get pod -n "${namespace}" -owide | grep "${key}" | awk '{print $1}')
  kubectl logs --tail=300 -c base-jre -n "${namespace}" -f "${pod}"
}

#--- skaffold
skapush() {
  namespace=$(getNamespace)
  skaffold run -p dev -n "${namespace:-aircpdev}"
}
skabuild() {
  skaffold run -p test
}
